# RentcastPropertyRecords200ResponseInnerHistory


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_2017_10_19** | [**RentcastPropertyRecords200ResponseInnerHistory20171019**](RentcastPropertyRecords200ResponseInnerHistory20171019.md) |  | [optional] 
**var_2024_11_18** | [**RentcastPropertyRecords200ResponseInnerHistory20241118**](RentcastPropertyRecords200ResponseInnerHistory20241118.md) |  | [optional] 

## Example

```python
from rentcast_client.models.rentcast_property_records200_response_inner_history import RentcastPropertyRecords200ResponseInnerHistory

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastPropertyRecords200ResponseInnerHistory from a JSON string
rentcast_property_records200_response_inner_history_instance = RentcastPropertyRecords200ResponseInnerHistory.from_json(json)
# print the JSON string representation of the object
print(RentcastPropertyRecords200ResponseInnerHistory.to_json())

# convert the object into a dict
rentcast_property_records200_response_inner_history_dict = rentcast_property_records200_response_inner_history_instance.to_dict()
# create an instance of RentcastPropertyRecords200ResponseInnerHistory from a dict
rentcast_property_records200_response_inner_history_from_dict = RentcastPropertyRecords200ResponseInnerHistory.from_dict(rentcast_property_records200_response_inner_history_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


